       IDENTIFICATION DIVISION.
       PROGRAM-ID.    CBLCBLC2.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2019 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any non-commercial purpose and without fee is hereby      *
      * granted, provided the SimoTime copyright notice appear on all *
      * copies of the software. The SimoTime name or Logo may not be  *
      * used in any advertising or publicity pertaining to the use    *
      * of the software without the written permission of SimoTime    *
      * Technologies.                                                 *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any commercial purpose requires a fee to be paid to       *
      * SimoTime Technologies. Once the fee is received by SimoTime   *
      * the latest version of the software will be delivered and a    *
      * license will be granted for use within an enterprise,         *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used    *
      * in any advertising or publicity pertaining to the use of the  *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *                                                               *
      *****************************************************************
      *
      *****************************************************************
      * Source Member: CBLCBLC2.CBL
      *****************************************************************
      *
      * CBLCBLC2 - This is a called routine for KSDS,VSAM file I/O.
      *
      * CALLING PROTOCOL
      * ----------------
      * USE STANDARD PROCEDURE TO RUN OR ANIMATE.
      *
      * DESCRIPTION
      * -----------
      * This program will do KSDS, VSAM file I/O.
      *
      ****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1997/02/27 Simmons, Created program.
      * 1997/04/04 Simmons, Added code to display file status.
      *
      *****************************************************************
      *
       ENVIRONMENT DIVISION.
       INPUT-OUTPUT   SECTION.
      *
       FILE-CONTROL.
      *
           SELECT VKSD0080-FILE
                  ASSIGN       to VKSD0080
                  FILE STATUS  is VKSD0080-STATUS
                  ORGANIZATION is indexed
                  ACCESS MODE  is SEQUENTIAL
                  RECORD KEY   is VKSD0080-KEY.
      *
       DATA DIVISION.
       FILE SECTION.
      *
       FD  VKSD0080-FILE.
       01  VKSD0080-RECORD.
           02  VKSD0080-KEY    pic X(6).
           02  VKSD0080-DATA   pic X(74).

       WORKING-STORAGE SECTION.
      *
      *****************************************************************
      *    Data-structure for Title and Copyright...
      *    ------------------------------------------------------------
       01  SIM-TITLE.
           05  T1 pic X(11) value '* CBLCBLC2 '.
           05  T2 pic X(34) value 'Sample, COBOL for VSAM-KSDS I/O   '.
           05  T3 pic X(10) value ' v08.02.25'.
           05  T4 pic X(24) value ' http://www.simotime.com'.
       01  SIM-COPYRIGHT.
           05  C1 pic X(11) value '* CBLCBLC2 '.
           05  C2 pic X(20) value 'Copyright 1987-2019 '.
           05  C3 pic X(28) value '   SimoTime Technologies    '.
           05  C4 pic X(20) value ' All Rights Reserved'.
      *
      *****************************************************************
      *    Data-structure used within this program...
      *    ------------------------------------------------------------
       01  VKSD0080-STATUS.
           05  VKSD0080-STAT1      pic X.
           05  VKSD0080-STAT2      pic X.

      *****************************************************************
      * The following buffers are used to create a four-byte status   *
      * code that may be displayed.                                   *
      *****************************************************************
       01  IO-STATUS.
           05  IO-STAT1            pic X.
           05  IO-STAT2            pic X.
       01  TWO-BYTES-BINARY        pic 9(4) BINARY.
       01  TWO-BYTES-ALPHA         redefines TWO-BYTES-BINARY.
           05  TWO-BYTES-LEFT      pic X.
           05  TWO-BYTES-RIGHT     pic X.
       01  IO-STATUS-04.
           05  IO-STATUS-0401      pic 9   value 0.
           05  IO-STATUS-0403      pic 999 value 0.

      *****************************************************************
      *    Buffer used for posting messages to the console.
      *****************************************************************
       01  MESSAGE-BUFFER.
           05  MESSAGE-HEADER      pic X(11)   value '* CBLCBLC2 '.
           05  MESSAGE-TEXT.
               10  MESSAGE-TEXT-1  pic X(68)   value SPACES.
               10  MESSAGE-TEXT-2  pic X(188)  value SPACES.

       01  REQUEST-OPEN            pic X(8)    value 'OPEN    '.
       01  REQUEST-GET             pic X(8)    value 'GET     '.
       01  REQUEST-CLOSE           pic X(8)    value 'CLOSE   '.
       01  REQUEST-KEY             pic X(6).

       01  FIRST-TIME              pic X       value 'Y'.

      *****************************************************************
       LINKAGE SECTION.
      *    Data Structure used for passing the address or an address
      *    list of a data string or strings..
      *    The Procedure Division statement must also be as follows...
      *    The PROCEDURE DIVISION using PASS-AREA.
      *
       01  PASS-AREA.
           05  PASS-REQUEST            pic X(8).
           05  PASS-RESULT             pic S9(9)   comp.
               88  NORMAL-RESULT       value 0.
               88  COBOL-RESULT-SAME   value 8.
               88  EOF-RESULT          value 16.
           05  PASS-RECORD.
               10  PASS-KEY            pic X(6).
               10  PASS-INFO           pic X(74).

      *****************************************************************
       PROCEDURE DIVISION using PASS-AREA.

       MAIN-ROUTINE.

           if  FIRST-TIME not = 'N'
               perform Z-POST-COPYRIGHT
               move 'N' to FIRST-TIME
           end-if

           evaluate PASS-REQUEST
               when REQUEST-GET    perform VKSD0080-GET
               when REQUEST-OPEN   perform VKSD0080-OPEN
               when REQUEST-CLOSE  perform VKSD0080-CLOSE
               when OTHER          perform INVALID-REQUEST
           end-evaluate

           GOBACK.

      *****************************************************************
       INVALID-REQUEST.
           display '* CBLCBLC2, Invalid Request, ' PASS-REQUEST
           add 24 to ZERO giving PASS-RESULT
           exit.

      *****************************************************************
       VKSD0080-GET.
           read VKSD0080-FILE INTO PASS-RECORD
           if  VKSD0080-STATUS = '00'
               subtract PASS-RESULT from PASS-RESULT
           else
               if  VKSD0080-STATUS = '10'
                   add 16 to ZERO giving PASS-RESULT
               else
                   add 12 to ZERO giving PASS-RESULT
                   display '* CBLCBLC2 VKSD0080-Failed-READ-attempt...'
                      upon console
                   move VKSD0080-STATUS to IO-STATUS
                   perform Z-DISPLAY-IO-STATUS
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       VKSD0080-OPEN.
           open input VKSD0080-FILE
           if  VKSD0080-STATUS = '00'
               subtract PASS-RESULT from PASS-RESULT
           else
               add 12 to ZERO giving PASS-RESULT
               display '* CBLCBLC2 VKSD0080-Failed-OPEN-attempt...'
                  upon console
               move VKSD0080-STATUS to IO-STATUS
               perform Z-DISPLAY-IO-STATUS
           end-if
           exit.
      *---------------------------------------------------------------*
       VKSD0080-CLOSE.
           close VKSD0080-FILE
           if  VKSD0080-STATUS = '00'
               subtract PASS-RESULT from PASS-RESULT
           else
               add 12 to ZERO giving PASS-RESULT
               display '* CBLCBLC2 VKSD0080-Failed-CLOSE-attempt...'
                  upon console
               move VKSD0080-STATUS to IO-STATUS
               perform Z-DISPLAY-IO-STATUS
           end-if
           exit.

      *****************************************************************
      * The following Z-Routines perform administrative functions     *
      * for this program.                                             *
      *****************************************************************

      *****************************************************************
      * Display the file status bytes. This routine will display as   *
      * four digits. If the full two byte file status is numeric it   *
      * will display as 00nn. If the 1st byte is a numeric nine (9)   *
      * the second byte will be treated as a binary number and will   *
      * display as 9nnn.                                              *
      *****************************************************************
       Z-DISPLAY-IO-STATUS.
           if  IO-STATUS not NUMERIC
           or  IO-STAT1 = '9'
               move IO-STAT1 to IO-STATUS-04(1:1)
               subtract TWO-BYTES-BINARY from TWO-BYTES-BINARY
               move IO-STAT2 to TWO-BYTES-RIGHT
               add TWO-BYTES-BINARY to ZERO giving IO-STATUS-0403
               move 'File Status is: nnnn' to MESSAGE-TEXT
               move IO-STATUS-04 to MESSAGE-TEXT(17:4)
               perform Z-DISPLAY-MESSAGE-TEXT
           else
               move '0000' to IO-STATUS-04
               move IO-STATUS to IO-STATUS-04(3:2)
               move 'File Status is: nnnn' to MESSAGE-TEXT
               move IO-STATUS-04 to MESSAGE-TEXT(17:4)
               perform Z-DISPLAY-MESSAGE-TEXT
           end-if
           exit.

      *****************************************************************
      * Display CONSOLE messages...                                   *
      *****************************************************************
       Z-DISPLAY-MESSAGE-TEXT.
           if MESSAGE-TEXT-2 = SPACES
               display MESSAGE-BUFFER(1:79) upon console
           else
               display MESSAGE-BUFFER upon console
           end-if
           move all SPACES to MESSAGE-TEXT
           exit.

      *****************************************************************
       Z-POST-COPYRIGHT.
           display SIM-TITLE     upon console
           display SIM-COPYRIGHT upon console
           exit.
      *****************************************************************
      *      This example is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
