@echo OFF
rem  * ************************************************************************
rem  *                 MKC080W8.CMD - a Windows Command File                  *
rem  *           This program is provided by SimoTime Technologies            *
rem  *              (C) Copyright 1987-2019 All Rights Reserved               *
rem  *                Web Site URL:   http://www.simotime.com                 *
rem  *                      e-mail:   helpdesk@simotime.com                   *
rem  * ************************************************************************
rem  *
rem  * Text   - Create various data files with 80-byte records.
rem  * Author - SimoTime Technologies
rem  * Date   - January 24, 1996
rem  *
rem  * This procedure uses the Microsoft "ECHO" command to pipe instream
rem  * data to an ASCII/Text file. The following terms are used.
rem  *
rem  * LSEQ - a Line Sequential File or ASCII/Text File
rem  * RSEQ - a Record Sequential File. This example uses a file of
rem  *        80-byte records that may be ASCII or EBCDIC encoded.
rem  * KSDS - a VSAM Key-Sequenced-Data-Set.
rem  *
rem  * 1. Delete previously created data file.
rem  * 2. Use the Windows "ECHO" function to Create an LSEQ file to be
rem  *    used as input to create additional files or data structures.
rem  * 3. Read the LSEQ file and write an RSEQ, ASCII File.
rem  * 4. Read the RSEQ, ASCII file and write a KSDS, ASCII File.
rem  * 5. Use "ECHO" to define keys to Hex-dump.
rem  * 6. Save the key-list to an RSEQ File.
rem  * 7. Do the Hex-Dump of the requested records.
rem  * 8. Convert Hex-dump (RSEQ) to ASCII/Text (LSEQ).
rem  *
rem  * *******************************************************************
rem  * Step 1 of 8, Delete any previously created file...
rem  *
     call ..\Env1BASE
     set CmdName=MKC080W8
rem  *
     call SimoNOTE "*******************************************************%CmdName%"
     call SimoNOTE "Starting JobName %CmdName% - v16.01.01"
     call SimoNOTE "Identify JobStep 1. Delete the LSEQ Data File"
     set CU80LSEQ=%BaseLib1%\DATA\TXT1\SIMOTIME.DATA.CU80LSEQ.txt
     if exist %CU80LSEQ% del %CU80LSEQ%
rem  *
rem  * *******************************************************************
rem  * Step 2 of 8, Create a new output file. Use the "echo" command
rem  *              provided with Microsoft Windows to pipe instream
rem  *              data to a new ASCII/Text file.
rem  *
     call SimoNOTE "Identify JobStep 2. Create the LSEQ Data File"
rem  ....:....1....:....2....:....3....:....4....:....5....:....6....:....7....:....8
echo 000100 Anderson       Adrian    111 Peachtree Plaza     Atlanta        GA 26101 >%CU80LSEQ%
echo 000200 Brown          Billie    222 Baker Boulevard     Baltimore      MD 35702 >>%CU80LSEQ%
echo 000300 Carson         Cameron   333 Crenshaw Blvd.      Cupertino      CA 96154 >>%CU80LSEQ%
echo 000400 Davidson       Dion      444 Main Street         Wilmington     DE 27323 >>%CU80LSEQ%
echo 000500 Everest        Evan      555 5TH Avenue          New York       NY 10341 >>%CU80LSEQ%
echo 000600 Franklin       Francis   666 66TH Avenue         Bedrock        NY 11903 >>%CU80LSEQ%
echo 000700 Garfunkel      Gwen      777 77TH Street         New York       NY 16539 >>%CU80LSEQ%
echo 000800 Harrison       Hilary    888 88TH Street         Pocatello      ID 79684 >>%CU80LSEQ%
echo 000900 Isley          Isabel    999 99TH Avenue         Indianapolis   IN 38762 >>%CU80LSEQ%
echo 001000 Johnson        Jamie     1010 Paradise Drive     Larkspur       CA 90504 >>%CU80LSEQ%
echo 001100 Kemper         Kelly     1111 Oak Circle         Kansas City    KS 55651 >>%CU80LSEQ%
echo 001200 Lemond         Lesley    1212 Lockwood Road      Mohave Desert  AZ 80303 >>%CU80LSEQ%
echo 001300 Mitchell       Marlow    1313 Miller Creek Road  Anywhere       TX 77123 >>%CU80LSEQ%
echo 001400 Newman         Noel      1414 Park Avenue        Santa Monica   CA 90210 >>%CU80LSEQ%
echo 001500 Osborn         Owen      1515 Center Stage       Rolling Rock   PA 36613 >>%CU80LSEQ%
echo 001600 Powell         Pierce    PO Box 1616             Ventura        CA 97712 >>%CU80LSEQ%
echo 001700 Quigley        Quincy    1717 Farm Hill Road     Oshkosh        WI 43389 >>%CU80LSEQ%
echo 001800 Ripley         Ray       1818 Alien Lane         Wayout         KS 55405 >>%CU80LSEQ%
echo 001900 Smith          Sammy     1919 Carnoustie Drive   Novato         CA 94919 >>%CU80LSEQ%
echo 002000 Tucker         Taylor    2020 Sanger Lane        St. Paul       MN 43998 >>%CU80LSEQ%
echo 002100 Underwood      Ulysses   2121 Wall Street        New York       NY 17623 >>%CU80LSEQ%
echo 002200 Van Etten      Valerie   2222 Vine Street        Hollywood      CA 98775 >>%CU80LSEQ%
echo 002300 Wilson         Wiley     2323 Main Street        Boston         MA 01472 >>%CU80LSEQ%
echo 002400 Xray           Xavier    2424 24TH Street        Nashville      TN 44190 >>%CU80LSEQ%
echo 002500 Young          Yanni     2525 Yonge Street       Toronto        ON 6B74A6>>%CU80LSEQ%
echo 002600 Zenith         Zebulon   2626 26TH Street        Dallas         TX 71922 >>%CU80LSEQ%
echo 123456 Doe            John      123 Main Street         Anywhere       OR 88156 >>%CU80LSEQ%
rem  *
     if not exist %CU80LSEQ% set JobStatus=0002
     if not "%JobStatus%" == "0000" goto EojNok
rem  *
rem  * *******************************************************************
rem  * Step 3 of 8, Read the previously created Line Sequential File
rem  *              and write a Record Sequential File with 80-byte,
rem  *              ASCII-encoded records.
rem  *
     call SimoNOTE "Identify JobStep 3. Convert LSEQ File to RSEQ File"
     set GETLS080=%CU80LSEQ%
     set PUTRS080=%BaseLib1%\DATA\ASC1\SIMOTIME.DATA.CU80RSEQ.DAT
     if exist %PUTRS080% del %PUTRS080%
     run CV80ALAR
     if not exist %PUTRS080% set JobStatus=0003
     if not "%JobStatus%" == "0000" goto EojNok
     set CU80RSEQ=%PUTRS080%
rem  *
rem  * *******************************************************************
rem  * Step 4 of 8, Read a previously created Record Sequential File and
rem  *              write to a VSAM, KSDS with 80-byte, ASCII-encoded
rem  *              records. The key positions are 1-6.
rem  *
     call SimoNOTE "Identify JobStep 4. Convert RSEQ File to VSAM KSDS"
     set QSAM0080=%BaseLib1%\DATA\ASC1\SIMOTIME.DATA.CU80QSAM.DAT
     set KSDS0080=%BaseLib1%\DATA\ASC1\SIMOTIME.DATA.CU80KSDS.DAT
     if exist %KSDS0080% del %KSDS0080%
     run KSLOADC1
     if not exist %KSDS0080% set JobStatus=0004
     if not "%JobStatus%" == "0000" goto EojNok
rem  *
rem  * *******************************************************************
rem  * Step 5 of 8, Define records to be Hex-Dumped.
rem  * Note: the dump information will be written to the SYSUT2 file.
rem  * *******************************************************************
rem  *
     call SimoNOTE "Identify JobStep 5. Define records to be Hex-Dumped"
     set SYSUT1=%KSDS0080%
     set SYSUT2=%BaseLib1%\DATA\ASC1\SIMOTIME.DATA.CU80DUMP.DAT
     set SYSUT3=%BaseLib1%\DATA\ASC1\SIMOTIME.DATA.CU80KEYS.DAT
     set GETLS080=%BaseLib1%\DATA\ASC1\SIMOTIME.DATA.CU80WORK.TXT
     set PUTRS080=%SYSUT3%
     echo /USERKEY   000100>%GETLS080%
     echo /USERKEY   000200>>%GETLS080%
rem  *
rem  * *******************************************************************
rem  * Step 6 of 8, Convert ASCII/Text (LSEQ) to Record Sequential (RSEQ)
rem  * *******************************************************************
rem  *
     call SimoNOTE "Identify JobStep 6. Store the Hex-Dump List in SYSUT3"
     if exist %PUTRS080% del %PUTRS080%
     run CV80ALAR
rem  *
rem  * *******************************************************************
rem  * Step 7 of 8, Execute the HEX Dump program.
rem  * Note: the dump information will be written to the SYSUT2 file.
rem  * *******************************************************************
rem  * Dump the content of the user-defined records within a VSAM, KSDS.
rem  * The results of the dump processing is posted to the SYSUT2 File.
rem  *
     call SimoNOTE "Identify JobStep 7. Dump the Requested Records"
     run HX80KSC3
rem  *
rem  * *******************************************************************
rem  * Step 8 of 8, Convert Hex-dump (RSEQ) to ASCII/Text (LSEQ)
rem  * *******************************************************************
rem  *
     call SimoNOTE "Identify JobStep 8. Hex-Dump SYSUT2 to ASCII/Text"
     set GETRS080=%SYSUT2%
     set PUTLS080=%BaseLib1%\DATA\ASC1\SIMOTIME.DATA.CU80DUMP.TXT
     if exist %PUTLS080% del %PUTLS080%
     run CV80ARAL
rem  *
rem  * *******************************************************************
rem  *
:EojAok
     call SimoNOTE "Produced DataSet %CU80LSEQ%"
     call SimoNOTE "Produced DataSet %CU80RSEQ%"
     call SimoNOTE "Produced DataSet %KSDS0080%"
     call SimoNOTE "Produced DataSet %GETLS080%"
     call SimoNOTE "Produced DataSet %SYSUT3%"
     call SimoNOTE "Produced DataSet %SYSUT2%"
     call SimoNOTE "Produced DataSet %PUTLS080%"
     call SimoNOTE "Finished JobName %CmdName%, Job Status is %JobStatus%"
     goto :End
:EojNok
     call SimoNOTE "ABENDING JobName %CmdName%, Job Status is %JobStatus%"
:End
     if not "%1" == "nopause" pause
